@@ -13,6 +13,7 @@ use File::Spec;
 use File::Basename;
 use Hash::Merge qw( merge );
 use Hash::Flatten qw(flatten unflatten);
+use Params::Get;
 
 =head1 NAME
 
@@ -20,11 +21,11 @@ Config::Abstraction - Configuration Abstraction Layer
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -207,29 +208,13 @@ If true, returns a flat configuration structure like C<'database.user'> (default
 
 sub new {
 	my $class = shift;
-
-	# Handle hash or hashref arguments
-	my %args;
-	if(@_ == 1) {
-		if(ref $_[0] eq 'HASH') {
-			# If the first argument is a hash reference, dereference it
-			%args = %{$_[0]};
-		} else {
-			$args{'logger'} = shift;
-		}
-	} elsif((scalar(@_) % 2) == 0) {
-		# If there is an even number of arguments, treat them as key-value pairs
-		%args = @_;
-	} else {
-		# If there is an odd number of arguments, treat it as an error
-		croak(__PACKAGE__, ': Invalid arguments passed to new()');
-	}
+	my $params = Params::Get::get_params(undef, @_) || {};
 
 	my $self = bless {
-		%args,
-		config_dirs => $args{config_dirs} || ['config'],
-		env_prefix => $args{env_prefix} || 'APP_',
-		flatten	 => $args{flatten} // 0,
+		%{$params},
+		config_dirs => $params->{config_dirs} || ['config'],
+		env_prefix => $params->{env_prefix} || 'APP_',
+		flatten	 => $params->{flatten} // 0,
 		config	=> {},
 	}, $class;
 
@@ -265,29 +250,47 @@ sub _load_config
 				$data = { map {
 					my $section = $_;
 					$section => { map { $_ => $ini->val($section, $_) } $ini->Parameters($section) }
-				} $ini->Sections };
+				} $ini->Sections() };
 			}
 			%merged = %{ merge( $data, \%merged ) };
 		}
-		# Put $self->{config_file} through all parsers, ignoring all errors, then merge that in
 
+		# Put $self->{config_file} through all parsers, ignoring all errors, then merge that in
 		if(my $config_file = $self->{'config_file'}) {
 			my $path = File::Spec->catfile($dir, $config_file);
 			if((-f $path) && (-r $path)) {
-				my $data;
+				my $data = read_file($path);
 				eval {
-					$data = LoadFile($path) or
-						decode_json(read_file($path)) or
-						XMLin($path, ForceArray => 0, KeyAttr => []);
-					if((!defined($data)) && (my $ini = Config::IniFiles->new(-file => $path))) {
-						$data = { map {
-							my $section = $_;
-							$section => { map { $_ => $ini->val($section, $_) } $ini->Parameters($section) }
-						} $ini->Sections };
+					if($data =~ /^\s*<\?xml/) {
+						$data = XMLin($path, ForceArray => 0, KeyAttr => []);
+					} else {
+						eval { $data = decode_json($data) };
+						if($@) {
+							undef $data;
+						}
+					}
+					if(!$data) {
+						$data = LoadFile($path);
+					}
+					if(!$data) {
+						if(my $ini = Config::IniFiles->new(-file => $path)) {
+							$data = { map {
+								my $section = $_;
+								$section => { map { $_ => $ini->val($section, $_) } $ini->Parameters($section) }
+							} $ini->Sections() };
+						}
+					}
+					if(!$data) {
+						# Maybe XML without the leading XML header
+						$data = XMLin($path, ForceArray => 0, KeyAttr => []);
 					}
 				};
-				if($data) {
-					%merged = %{ merge( $data, \%merged ) };
+				if(scalar(keys %merged)) {
+					if($data) {
+						%merged = %{ merge( $data, \%merged ) };
+					}
+				} else {
+					%merged = %{$data};
 				}
 			}
 		}
@@ -326,9 +329,11 @@ C<'database.user'>). Returns C<undef> if the key doesn't exist.
 
 =cut
 
-sub get {
+sub get
+{
 	my ($self, $key) = @_;
-	if ($self->{flatten}) {
+
+	if($self->{flatten}) {
 		return $self->{config}{$key};
 	}
 	my $ref = $self->{config};
@@ -341,12 +346,13 @@ sub get {
 
 =head2 all()
 
-Returns the entire configuration hash, possibly flattened depending on the
-C<flatten> option.
+Returns the entire configuration hash,
+possibly flattened depending on the C<flatten> option.
 
 =cut
 
-sub all {
+sub all
+{
 	my $self = shift;
 
 	return $self->{'config'};
